from ai_dashboard.tabs.data_report import *
from ai_dashboard.tabs.category_view import *
from ai_dashboard.tabs.chart_view import *
from ai_dashboard.tabs.document_view import *
from ai_dashboard.tabs import block